@@ -24,17 +24,17 @@
 #' The \code{fapply} function will process any of the following types of
 #' formats:
 #' \itemize{
-#'   \item{\strong{Formatting string:}}{ A single string will be interpreted as 
+#'   \item{\strong{Formatting string:} A single string will be interpreted as 
 #' a formatting string.  See the \link{FormattingStrings} documentation for 
 #' further details.}
-#'   \item{\strong{Named vector:}}{ A named vector can serve as a lookup list or 
+#'   \item{\strong{Named vector:} A named vector can serve as a lookup list or 
 #'   decode 
 #' for a vector.  You can use a named vector to perform simple 
 #' lookups on character vectors.}
-#'   \item{\strong{Format object:}}{ A format object may be created using the 
+#'   \item{\strong{Format object:} A format object may be created using the 
 #' \code{\link{value}} function.  The format object is included in the 
 #' \strong{fmtr} package, and is specially designed for data categorization.}  
-#'   \item{\strong{Vectorized formatting function:}}{ A vectorized function 
+#'   \item{\strong{Vectorized formatting function:} A vectorized function 
 #'   provides
 #' the most flexibility and power over your formatting.  You can use 
 #' an existing formatting function from any package, or create 
@@ -217,6 +217,13 @@ fapply <- function(x, format = NULL, width = NULL, justify = NULL) {
     ret <- mapply(eval_conditions, x, MoreArgs = list(conds = format))
     names(ret) <- NULL  # Names not needed and mess up stuff
     
+    if (!is.null(attr(format, "as.factor"))) {
+      if (attr(format, "as.factor") == TRUE) {
+         ret <- factor(ret, levels = labels(format), ordered = TRUE)
+         
+      }
+    }
+    
   } else if (is.flist(format)) {
     
     # For flist class, call row or column functions as appropriate
